@@ -64,6 +64,17 @@ namespace Docky.Items
 		string forced_hover_text;
 		string backup_icon;
 		
+		public string ForcedHoverText {
+			get { return forced_hover_text; }
+			set {
+				if (forced_hover_text == value)
+					return;
+				forced_hover_text = value;
+				if (!string.IsNullOrEmpty (forced_hover_text))
+					HoverText = forced_hover_text;
+			}
+		}
+		
 		public string Uri {
 			get { return uri; }
 		}
@@ -145,10 +156,10 @@ namespace Docky.Items
 				Icon = "";
 			}
 
-			if (string.IsNullOrEmpty (forced_hover_text))
+			if (string.IsNullOrEmpty (ForcedHoverText))
 			    HoverText = OwnedFile.Basename;
 			else
-				HoverText = forced_hover_text;
+				HoverText = ForcedHoverText;
 			
 			OnPaintNeeded ();
 		}
@@ -208,7 +219,7 @@ namespace Docky.Items
 					long cur = 0, tot = 10;
 					
 					if (note == null) {
-						note = Docky.Services.Log.Notify ("", file.Icon (), "{0}% " + Catalog.GetString ("Complete") + "...", cur / tot);
+						note = Docky.Services.Log.Notify ("", file.Icon (), string.Format ("{0}% " + Catalog.GetString ("Complete") + "...", cur / tot));
 						
 						GLib.Timeout.Add (250, () => {
 							note.Body = string.Format ("{0:00.0}% ", ((float) Math.Min (cur, tot) / tot) * 100) + Catalog.GetString ("Complete") + "...";
@@ -251,7 +262,7 @@ namespace Docky.Items
 		
 		protected override ClickAnimation OnClicked (uint button, Gdk.ModifierType mod, double xPercent, double yPercent)
 		{
-			if (button == 1) {
+			if (button == 1 || button == 2) {
 				Open ();
 				return ClickAnimation.Bounce;
 			}
