@@ -141,6 +141,7 @@ namespace Docky.Items
 		
 		void WindowStateChanged (object o, StateChangedArgs args)
 		{
+			SetIndicator ();
 			SetState ();
 		}
 
@@ -159,8 +160,6 @@ namespace Docky.Items
 			} else {
 				Indicator = ActivityIndicator.None;
 			}
-			
-			OnPaintNeeded ();
 		}
 		
 		void SetState ()
@@ -175,8 +174,6 @@ namespace Docky.Items
 			}
 			
 			State = state;
-			
-			OnPaintNeeded ();
 		}
 		
 		protected override void OnScrolled (Gdk.ScrollDirection direction, Gdk.ModifierType mod)
