@@ -46,12 +46,13 @@ namespace Docky.Services
 			}
 		}
 		
+		bool enabled;
 		public bool Enabled {
 			get {
-				return prefs.Get<bool> (prefs.SanitizeKey (File.Basename), false);
+				return enabled;
 			}
 			set {
-				if (Enabled == value)
+				if (enabled == value)
 					return;
 				
 				if (value)
@@ -59,7 +60,8 @@ namespace Docky.Services
 				else
 					Stop ();
 				
-				prefs.Set<bool> (prefs.SanitizeKey (File.Basename), value);
+				enabled = value;
+				prefs.Set<bool> (prefs.SanitizeKey (File.Basename), enabled);
 				OnHelperStatusChanged ();
 			}
 		}
@@ -76,6 +78,7 @@ namespace Docky.Services
 		{
 			File = file;
 			IsUser = file.Path.StartsWith ("/home/");
+			enabled = prefs.Get<bool> (prefs.SanitizeKey (File.Basename), false);
 			
 			GLib.File DataFile;
 			if (IsUser)
