@@ -60,26 +60,52 @@ namespace Docky.Services
 		const string PROXY_PASSWORD = PROXY + "/" + "authentication_password";
 		const string PROXY_BYPASS_LIST = PROXY + "/" + "ignore_hosts";
 		
+		IBus NetworkManagerBus;
+		
 		void InitializeNetwork ()
 		{
-			NetworkConnected = true;
-			try {
-				BusG.Init ();
-				if (Bus.System.NameHasOwner (NetworkManagerName)) {
-					network = Bus.System.GetObject<INetworkManager> (NetworkManagerName, new ObjectPath (NetworkManagerPath));
-					network.StateChanged += OnConnectionStatusChanged;
-					SetConnected ();
-				}
-			} catch (Exception e) {
-				// if something bad happened, log the error and assume we are connected
-				Log<SystemService>.Error ("Could not initialize Network Manager dbus: '{0}'", e.Message);
-				Log<SystemService>.Info (e.StackTrace);
-			}
+			NetworkManagerBus = Bus.System.GetObject<IBus> ("org.freedesktop.DBus", new ObjectPath ("/org/freedesktop/DBus"));
+			NetworkManagerBus.NameOwnerChanged += delegate(string name, string old_owner, string new_owner) {
+				if (name != NetworkManagerName)
+					return;
+				Log<SystemService>.Debug ("DBus services changed, reconnecting to Network Manager");
+				network = null;
+			};
+			InitializeNetworkManager ();
 			
 			GConf.AddNotify (PROXY, ProxySettingsChanged);
 			Proxy = GetWebProxy ();
 		}
 		
+		uint nmTimer = 0;
+		
+		void InitializeNetworkManager ()
+		{
+			NetworkConnected = true;
+			if (nmTimer != 0) {
+				GLib.Source.Remove (nmTimer);
+				nmTimer = 0;
+			}
+			
+			if (Bus.System.NameHasOwner (NetworkManagerName)) {
+				try {
+					network = Bus.System.GetObject<INetworkManager> (NetworkManagerName, new ObjectPath (NetworkManagerPath));
+					NetworkConnected = State == NetworkState.Connected;
+					network.StateChanged += OnConnectionStatusChanged;
+					nmTimer = GLib.Timeout.Add (1 * 60 * 1000, () => { 
+						NetworkConnected = State == NetworkState.Connected;
+						return true;
+					});
+				} catch (Exception e) {
+					// if something bad happened, log the error and assume we are connected
+					Log<SystemService>.Error ("Could not initialize Network Manager dbus: '{0}'", e.Message);
+					Log<SystemService>.Info (e.StackTrace);
+				}
+			} else {
+				Log<SystemService>.Error ("Network Manager is not available.");
+			}
+		}
+		
 		public event EventHandler<ConnectionStatusChangeEventArgs> ConnectionStatusChanged;
 		
 		const string NetworkManagerName = "org.freedesktop.NetworkManager";
@@ -99,18 +125,18 @@ namespace Docky.Services
 		void OnConnectionStatusChanged (uint state)
 		{
 			NetworkState newState = (NetworkState) Enum.ToObject (typeof (NetworkState), state);
-			SetConnected ();
+			NetworkConnected = newState == NetworkState.Connected;
 			
-			if (ConnectionStatusChanged != null)
-				ConnectionStatusChanged (this, new ConnectionStatusChangeEventArgs (newState));
-		}
-		
-		void SetConnected ()
-		{
-			if (State == NetworkState.Connected)
-				NetworkConnected = true;
-			else
-				NetworkConnected = false;
+			if (ConnectionStatusChanged != null) {
+				Delegate [] handlers = ConnectionStatusChanged.GetInvocationList ();
+				foreach (Delegate d in handlers)
+					try {
+						d.DynamicInvoke (new object [] {this, new ConnectionStatusChangeEventArgs (newState)});
+					} catch (Exception e) {
+						Log.Error ("Error in ConnectionStatusChanged handler, {0}", e.Message);
+						Log.Debug (e.StackTrace);
+					}
+			}
 		}
 		
 		NetworkState State {
@@ -190,8 +216,16 @@ namespace Docky.Services
 		
 		void OnBatteryStateChanged ()
 		{
-			if (BatteryStateChanged != null)
-				BatteryStateChanged (this, EventArgs.Empty);
+			if (BatteryStateChanged != null) {
+				Delegate [] handlers = BatteryStateChanged.GetInvocationList ();
+				foreach (Delegate d in handlers)
+					try {
+						d.DynamicInvoke (new object [] {this, EventArgs.Empty});
+					} catch (Exception e) {
+						Log.Error ("Error in BatteryStateChanged handler, {0}", e.Message);
+						Log.Debug (e.StackTrace);
+					}
+			}
 		}
 		
 		const string PowerManagementName = "org.freedesktop.PowerManagement";
@@ -441,6 +475,14 @@ namespace Docky.Services
 			}
 		}
 		
+		public bool IsValidExecutable (string Executable)
+		{
+			foreach (string path in Environment.GetEnvironmentVariable ("PATH").Split (':'))
+				if (System.IO.File.Exists (path + "/" + Executable))
+					return true;
+			return false;
+		}
+		
 		public System.Threading.Thread RunOnThread (Action action, TimeSpan delay)
 		{
 			return RunOnThread (() => {
