@@ -312,7 +312,7 @@ namespace Docky.Windowing
 		
 		public bool WindowIsReadyForMatch (Wnck.Window window)
 		{
-			if (!WindowIsOpenOffice (window))
+			if (!WindowIsOpenOffice (window) && !WindowIsLibreOffice (window))
 				return true;
 			SetupWindow (window);
 			string win = window_to_desktop_files[window].FirstOrDefault ();
@@ -325,6 +325,11 @@ namespace Docky.Windowing
 			return window.ClassGroup != null && window.ClassGroup.Name.ToLower ().StartsWith ("openoffice");
 		}
 		
+		public bool WindowIsLibreOffice (Window window)
+		{
+			return window.ClassGroup != null && window.ClassGroup.Name.ToLower ().StartsWith ("libreoffice");
+		}
+
 		IEnumerable<string> DesktopFilesForDesktopID (string id)
 		{
 			IEnumerable<string> matches = Enumerable.Empty<string> ();
@@ -369,7 +374,6 @@ namespace Docky.Windowing
 			}
 			
 			bool matched = false;
-			int currentPid = 0;
 			
 			// get ppid and parents
 			IEnumerable<int> pids = PIDAndParents (pid);
@@ -391,6 +395,18 @@ namespace Docky.Windowing
 					} else if (title.EndsWith ("Math")) {
 						command_line.Add ("ooffice-math");
 					}
+				} else if (WindowIsLibreOffice (window)) {
+					string title = window.Name.Trim ();
+					if (title.EndsWith ("Writer"))
+						command_line.Add ("libreoffice-writer");
+					else if (title.EndsWith ("Draw"))
+						command_line.Add ("libreoffice-draw");
+					else if (title.EndsWith ("Impress"))
+						command_line.Add ("libreoffice-impress");
+					else if (title.EndsWith ("Calc"))
+						command_line.Add ("libreoffice-calc");
+					else if (title.EndsWith ("Math"))
+						command_line.Add ("libreoffice-math");
 				} else if (window.ClassGroup.ResClass == "Wine") {
 					// we can match Wine apps normally so don't do anything here
 				} else {
@@ -405,9 +421,9 @@ namespace Docky.Windowing
 			}
 	
 			lock (update_lock) {
-				do {
+				foreach (int currentPid in pids) {
 					// do a match on the process name
-					string name = NameForPid (pids.ElementAt (currentPid));
+					string name = NameForPid (currentPid);
 					if (exec_to_desktop_files.ContainsKey (name)) {
 						foreach (string s in exec_to_desktop_files[name]) {
 							if (string.IsNullOrEmpty (s))
@@ -418,8 +434,8 @@ namespace Docky.Windowing
 					}
 					
 					// otherwise do a match on the commandline
-					command_line.AddRange (CommandLineForPid (pids.ElementAt (currentPid++))
-						.Select (cmd => cmd.Replace (@"\", @"\\")));
+					command_line.AddRange (CommandLineForPid (currentPid)
+					                      .Select (cmd => cmd.Replace (@"\", @"\\")));
 					if (command_line.Count () == 0)
 						continue;
 					foreach (string cmd in command_line) {
@@ -437,7 +453,7 @@ namespace Docky.Windowing
 					// if we found a match, bail.
 					if (matched)
 						yield break;
-				} while (currentPid < pids.Count ());
+				}
 			}
 			command_line.Clear ();
 			// if no match was found, just return the pid
@@ -578,6 +594,9 @@ namespace Docky.Windowing
 					if (item == null || !item.HasAttribute ("StartupWMClass"))
 						continue;
 					
+					if (item.HasAttribute ("Hidden") && item.GetBool ("Hidden"))
+						continue;
+					
 					if (item.HasAttribute ("NoDisplay") && item.GetBool ("NoDisplay"))
 						continue;
 					
@@ -604,16 +623,26 @@ namespace Docky.Windowing
 					if (item == null || !item.HasAttribute ("Exec"))
 						continue;
 					
+					if (item.HasAttribute ("Hidden") && item.GetBool ("Hidden"))
+						continue;
+					
 					if (item.HasAttribute ("X-Docky-NoMatch") && item.GetBool ("X-Docky-NoMatch"))
 						continue;
 					
 					string exec = item.GetString ("Exec").Trim ();
 					string vexec = null;
 					
+					// for openoffice
 					if (exec.Contains (' ') &&
 					    (exec.StartsWith ("ooffice") || exec.StartsWith ("openoffice") || exec.StartsWith ("soffice") ||
 					     exec.Contains ("/ooffice ") || exec.Contains ("/openoffice.org ") || exec.Contains ("/soffice "))) {
 						vexec = "ooffice" + exec.Split (' ') [1];
+						
+					// for libreoffice
+					} else if (exec.Contains (' ') &&
+					           (exec.StartsWith ("libreoffice"))) {
+						vexec = "libreoffice" + exec.Split (' ')[1];
+				
 					// for wine apps
 					} else if ((exec.Contains ("env WINEPREFIX=") && exec.Contains (" wine ")) ||
 							exec.Contains ("wine ")) {
