@@ -17,7 +17,6 @@
 
 using System.Reflection;
 using System.Runtime.CompilerServices;
-using Mono.GetOptions;
 
 // Information about this assembly is defined by the following
 // attributes.
@@ -33,20 +32,13 @@ using Mono.GetOptions;
 [assembly: AssemblyTrademark("")]
 [assembly: AssemblyCulture("")]
 
-[assembly: Mono.About ("For more information, please visit http://launchpad.net/docky/")]
-[assembly: Mono.Author ("Daniel For\u0233 <daniel.p.fore@gmail.com>")]
-[assembly: Mono.Author ("Chris Szikszoy <chris@szikszoy.com>")]
-[assembly: Mono.Author ("Robert Dyer <psybers@gmail.com>")]
-[assembly: Mono.Author ("Jason Smith <jassmith@gmail.com>")]
-[assembly: Mono.UsageComplement ("")]
-
 // The assembly version has following format:
 //
 // Major.Minor.Build.Revision
 //
 // You can specify all values by your own or you can build default build and revision
 // numbers with the '*' character (the default):
-[assembly: AssemblyVersion("1371")]
+[assembly: AssemblyVersion("1453")]
 
 // The following attributes specify the key for the sign of your assembly. See the
 // .NET Framework documentation for more information about signing.
@@ -58,8 +50,8 @@ namespace Docky
 {
 	internal static class AssemblyInfo
 	{
-		public const string DisplayVersion = "2.0.7";
-		public const string VersionDetails = "bzr docky-2.0 r1371";
+		public const string DisplayVersion = "2.0.13";
+		public const string VersionDetails = "bzr docky-2.0 r1453";
 		public const string LocaleDirectory = "/usr/share/locale";
 		public const string InstallData = "/usr/share";
 	}
