@@ -49,15 +49,15 @@ namespace Docky.CairoHelper
 			double cos, sin;
 			cos = Math.Cos (rotation);
 			sin = Math.Sin (rotation);
-			Matrix m = new Matrix (cos, sin, 0 - sin, cos, point.X, point.Y);
+			Matrix m = new Matrix (cos, sin, -sin, cos, point.X, point.Y);
 			cr.Transform (m);
 			
 			if (zoom != 1)
 				cr.Scale (zoom, zoom);
 			
 			cr.SetSource (self.Internal,
-				0 - self.Width / 2, 
-				0 - self.Height / 2);
+				-self.Width / 2, 
+				-self.Height / 2);
 			
 			cr.PaintWithAlpha (opacity);
 			
@@ -90,7 +90,7 @@ namespace Docky.CairoHelper
 			double cos, sin;
 			cos = Math.Cos (rotation);
 			sin = Math.Sin (rotation);
-			Matrix m = new Matrix (cos, sin, 0 - sin, cos, point.X, point.Y);
+			Matrix m = new Matrix (cos, sin, -sin, cos, point.X, point.Y);
 			cr.Transform (m);
 			
 			if (zoom != 1)
@@ -102,8 +102,8 @@ namespace Docky.CairoHelper
 				cr.Scale (1, -1);
 			
 			cr.SetSource (self.Internal, 
-				0 - self.Width / 2, 
-				0 - self.Height / 2);
+				-self.Width / 2, 
+				-self.Height / 2);
 			
 			cr.PaintWithAlpha (opacity * .3);
 			
@@ -215,17 +215,6 @@ namespace Docky.CairoHelper
 			}
 		}
 		
-		public static Gdk.Pixbuf LoadToPixbuf (this DockySurface self)
-		{
-			Gdk.Pixbuf pbuf;
-			string tmp = System.IO.Path.GetTempFileName ();
-			self.Internal.WriteToPng (tmp);
-			pbuf = new Pixbuf (tmp);
-			System.IO.File.Delete (tmp);
-
-			return pbuf;
-		}
-		
 		public static DockySurface CreateMask (this DockySurface self, double cutOff, out Gdk.Rectangle extents)
 		{
 			ImageSurface original = new ImageSurface (Format.ARGB32, self.Width, self.Height);
