@@ -31,6 +31,7 @@ using Gtk;
 using Docky.Items;
 using Docky.Services;
 using System.Text.RegularExpressions;
+using Mono.Addins;
 
 namespace Docky.Interface
 {
@@ -154,9 +155,8 @@ namespace Docky.Interface
 		int? icon_size;
 		public int IconSize {
 			get {
-				if (!icon_size.HasValue) {
-					icon_size = GetOption<int?> ("IconSize", 48);
-				}
+				if (!icon_size.HasValue)
+					icon_size = Clamp (GetOption<int> ("IconSize", 48), 128, 24);
 				return icon_size.Value;
 			}
 			set {
@@ -221,7 +221,7 @@ namespace Docky.Interface
 		public double ZoomPercent {
 			get {
 				if (!zoom_percent.HasValue)
-					zoom_percent = GetOption<double?> ("ZoomPercent", 2.0);
+					zoom_percent = Clamp (GetOption<double> ("ZoomPercent", 2.0), 4, 1);
 				return zoom_percent.Value;
 			}
 			set {
@@ -476,8 +476,10 @@ namespace Docky.Interface
 			multiple_window_indicator_check.Active = IndicateMultipleWindows;
 			
 			window_manager_check.Active = DefaultProvider.IsWindowManager;
+			window_manager_check.Sensitive = !window_manager_check.Active;
 			DefaultProvider.WindowManagerChanged += delegate {
 				WindowManager = window_manager_check.Active = DefaultProvider.IsWindowManager;
+				window_manager_check.Sensitive = !window_manager_check.Active;
 			};
 		}
 		
@@ -493,11 +495,6 @@ namespace Docky.Interface
 		
 		void BuildItemProviders ()
 		{
-			item_providers = new List<AbstractDockItemProvider> ();
-			
-			DefaultProvider = new FileApplicationProvider ();
-			item_providers.Add (DefaultProvider);
-			
 			if (FirstRun) {
 				WindowManager = true;
 				
@@ -545,31 +542,28 @@ namespace Docky.Interface
 				}.Where (s => !String.IsNullOrEmpty (s));
 			}
 			
-			foreach (string launcher in Launchers) {
+			item_providers = new List<AbstractDockItemProvider> ();
+			
+			DefaultProvider = new FileApplicationProvider ();
+			item_providers.Add (DefaultProvider);
+			
+			foreach (string launcher in Launchers)
 				DefaultProvider.InsertItem (launcher);
-			}
 			
-			// we have a plugin thats not enabled, go nuclear
-			if (Plugins.Any (s => !PluginManager.ItemProviders.Any (ip => ip.Name == s))) {
-				foreach (Mono.Addins.Addin addin in PluginManager.AllAddins) {
-					addin.Enabled = true;
-				}
-			}
-			
-			foreach (string providerName in Plugins) {
-				AbstractDockItemProvider provider = PluginManager.ItemProviders
-					.Where (adip => adip.Name == providerName)
-					.DefaultIfEmpty (null)
-					.FirstOrDefault ();
-				
+			foreach (string pluginId in Plugins) {
+				Addin addin = PluginManager.AllAddins.FirstOrDefault (a => a.LocalId == pluginId);
+				if (addin == null)
+					continue;
+				addin.Enabled = true;
+
+				AbstractDockItemProvider provider = PluginManager.ItemProviderFromAddin (addin.Id);
 				if (provider != null)
 					item_providers.Add (provider);
 			}
 			
 			List<string> sortList = SortList.ToList ();
-			foreach (AbstractDockItemProvider provider in item_providers) {
+			foreach (AbstractDockItemProvider provider in item_providers)
 				SortProviderOnList (provider, sortList);
-			}
 			
 			UpdateSortList ();
 		}
@@ -583,9 +577,8 @@ namespace Docky.Interface
 			};
 			
 			int i = 0;
-			foreach (AbstractDockItem item in provider.Items.OrderBy (indexFunc)) {
+			foreach (AbstractDockItem item in provider.Items.OrderBy (indexFunc))
 				item.Position = i++;
-			}
 		}
 		
 		void UpdateSortList ()
@@ -686,6 +679,7 @@ namespace Docky.Interface
 			if (window_manager_check.Active)
 				DefaultProvider.SetWindowManager ();
 			WindowManager = window_manager_check.Active = DefaultProvider.IsWindowManager;
+			window_manager_check.Sensitive = !window_manager_check.Active;
 		}
 		
 		protected virtual void OnPanelModeButtonToggled (object sender, System.EventArgs e)
@@ -711,7 +705,9 @@ namespace Docky.Interface
 		
 		void SyncPlugins ()
 		{
-			Plugins = ItemProviders.Where (p => p != DefaultProvider).Select (p => p.Name);
+			Plugins = item_providers.Where (p => p != DefaultProvider)
+				.Select (p => PluginManager.AddinFromID (PluginManager.AddinIDFromProvider (p)))
+				.Select (a => a.LocalId);
 		}
 
 		public void FreeProviders ()
