@@ -371,7 +371,7 @@ namespace Docky.Interface
 			return surface;
 		}
 		
-		void UpdateHoverText ()
+		internal void UpdateHoverText ()
 		{
 			int top = (int) (IconSize * (ZoomPercent + .2));
 			Gdk.Point point = new Gdk.Point (-1, -1);
@@ -730,8 +730,8 @@ namespace Docky.Interface
 			Wnck.Screen.Default.WindowOpened += HandleWindowOpened;
 			
 			// fix for nvidia bug
-			if (Docky.CommandLinePreferences.BufferTime > 0)
-				GLib.Timeout.Add (Docky.CommandLinePreferences.BufferTime * 60 * 1000, delegate {
+			if (UserArgs.BufferTime > 0)
+				GLib.Timeout.Add (UserArgs.BufferTime * 60 * 1000, delegate {
 					ResetBuffers ();
 					return true;
 				});
@@ -1269,7 +1269,7 @@ namespace Docky.Interface
 			AnimatedDraw ();
 		}
 		
-		void SetTooltipVisibility ()
+		internal void SetTooltipVisibility ()
 		{
 			bool visible = (HoveredItem != null && !InternalDragActive && !ExternalDragActive &&
 								!Menu.Visible && !ConfigurationMode && Painter == null) ||
@@ -1498,14 +1498,14 @@ namespace Docky.Interface
 			UpdateMonitorGeometry ();
 			
 			if (VerticalDock) {
-				Height = Math.Min (Docky.CommandLinePreferences.MaxSize, monitor_geo.Height);
+				Height = Math.Min (UserArgs.MaxSize, monitor_geo.Height);
 				Width = DockHeightBuffer + ZoomedIconSize + UrgentBounceHeight;
 			} else {
-				Width = Math.Min (Docky.CommandLinePreferences.MaxSize, monitor_geo.Width);
+				Width = Math.Min (UserArgs.MaxSize, monitor_geo.Width);
 				Height = DockHeightBuffer + ZoomedIconSize + UrgentBounceHeight;
 			}
 			
-			if (Docky.CommandLinePreferences.NetbookMode) {
+			if (UserArgs.NetbookMode) {
 				// Currently the intel i945 series of cards (used on netbooks frequently) will 
 				// for some mystical reason get terrible drawing performance if the window is
 				// between 1009 pixels and 1024 pixels in width OR height. We just pad it out an extra
@@ -1550,6 +1550,8 @@ namespace Docky.Interface
 				GLib.Source.Remove (animation_timer);
 			animation_timer = 0;
 
+			// one final draw to clean out the end of previous animations
+			QueueDraw ();
 			return false;
 		}
 		
@@ -1831,7 +1833,7 @@ namespace Docky.Interface
 				DrawValues[adi] = val;
 
 				// keep the hovereditem in mind, but don't change it while rendering
-				if (hoverArea.Contains (localCursor) && !AutohideManager.Hidden)
+				if (hoverArea.Contains (localCursor) && !AutohideManager.Hidden && !(adi is SeparatorItem))
 					next_hoveredItem = adi;
 				
 				if (update_screen_regions) {
@@ -1990,9 +1992,9 @@ namespace Docky.Interface
 				dockArea.Height = DockHeight;
 				
 				cursorArea = new Gdk.Rectangle (staticArea.X,
-				                                dockArea.Y,
+				                                -window_position.Y,
 				                                staticArea.Width,
-				                                hotAreaSize);
+				                                hotAreaSize + window_position.Y);
 				break;
 			case DockPosition.Left:
 				dockArea.X = 0;
@@ -2000,9 +2002,9 @@ namespace Docky.Interface
 				dockArea.Width = DockHeight;
 				dockArea.Height = dockWidth;
 				
-				cursorArea = new Gdk.Rectangle (dockArea.X,
+				cursorArea = new Gdk.Rectangle (-window_position.X,
 				                                staticArea.Y,
-				                                hotAreaSize,
+				                                hotAreaSize + window_position.X,
 				                                staticArea.Height);
 				break;
 			case DockPosition.Right:
@@ -2013,7 +2015,7 @@ namespace Docky.Interface
 				
 				cursorArea = new Gdk.Rectangle (dockArea.X + dockArea.Width - hotAreaSize,
 				                                staticArea.Y,
-				                                hotAreaSize,
+				                                hotAreaSize + (Screen.Width - monitor_geo.Width),
 				                                staticArea.Height);
 				break;
 			default:
@@ -2026,7 +2028,7 @@ namespace Docky.Interface
 				cursorArea = new Gdk.Rectangle (staticArea.X,
 				                                dockArea.Y + dockArea.Height - hotAreaSize,
 				                                staticArea.Width,
-				                                hotAreaSize);
+				                                hotAreaSize + (Screen.Height - monitor_geo.Height));
 				break;
 			}
 		}
@@ -2138,7 +2140,6 @@ namespace Docky.Interface
 			
 			cursorArea.X += window_position.X;
 			cursorArea.Y += window_position.Y;
-			cursorArea.Intersect (monitor_geo);
 			AutohideManager.SetCursorArea (cursorArea);
 		}
 		
@@ -2642,10 +2643,10 @@ namespace Docky.Interface
 				} else {
 					switch (Position) {
 					case DockPosition.Top:
-						cr.SetSource (main_buffer.Internal, 0, 0 - HideOffset * DockHeight);
+						cr.SetSource (main_buffer.Internal, 0, -HideOffset * DockHeight);
 						break;
 					case DockPosition.Left:
-						cr.SetSource (main_buffer.Internal, 0 - HideOffset * DockHeight, 0);
+						cr.SetSource (main_buffer.Internal, -HideOffset * DockHeight, 0);
 						break;
 					case DockPosition.Right:
 						cr.SetSource (main_buffer.Internal, HideOffset * DockHeight, 0);
@@ -2759,8 +2760,9 @@ namespace Docky.Interface
 			AutohideManager.HiddenChanged       -= HandleHiddenChanged;
 			AutohideManager.DockHoveredChanged  -= HandleDockHoveredChanged;
 			Screen.SizeChanged                  -= ScreenSizeChanged;
-			Docky.Controller.ThemeChanged       -= DockyControllerThemeChanged;
 			Wnck.Screen.Default.WindowOpened    -= HandleWindowOpened;
+			Realized                            -= HandleRealized;
+			Docky.Controller.ThemeChanged       -= DockyControllerThemeChanged;
 			
 			// clear out our separators
 			foreach (AbstractDockItem adi in Items.Where (adi => adi is INonPersistedItem && adi != DockyItem)) {
