@@ -70,9 +70,8 @@ namespace Bookmarks
 		
 		File BookmarksFile {
 			get {
-				if (bookmarks_file == null) {
+				if (bookmarks_file == null)
 					bookmarks_file = FileFactory.NewForPath (Environment.GetFolderPath (Environment.SpecialFolder.Personal)).GetChild (".gtk-bookmarks");
-				}
 				return bookmarks_file;
 			}
 		}
@@ -97,7 +96,7 @@ namespace Bookmarks
 		void WatcherChanged (object o, ChangedArgs args)
 		{
 			if (args.EventType == FileMonitorEvent.ChangesDoneHint)
-				Gtk.Application.Invoke ( delegate {
+				DockServices.System.RunOnMainThread ( delegate {
 					UpdateItems ();
 				});
 		}
@@ -125,12 +124,14 @@ namespace Bookmarks
 						FileDockItem item = old.Cast<FileDockItem> ().First (fdi => fdi.Uri == uri);
 						old.Remove (item);
 						items.Add (item);
+						item.ForcedHoverText = name;
 					} else if (bookmark.StringUri ().StartsWith ("file://") && !bookmark.Exists) {
-						Log<BookmarksItemProvider>.Warn ("Bookmark path '{0}' does not exist, please fix the bookmarks file",
-						    bookmark.StringUri ());
+						Log<BookmarksItemProvider>.Warn ("Bookmark path '{0}' does not exist, please fix the bookmarks file", bookmark.StringUri ());
 						continue;
 					} else {
-						items.Add (FileDockItem.NewFromUri (bookmark.StringUri (), name, "folder"));
+						FileDockItem item = FileDockItem.NewFromUri (bookmark.StringUri (), name, "folder");
+						if (item != null)
+							items.Add (item);
 					}
 				}
 			}
@@ -144,9 +145,7 @@ namespace Bookmarks
 		#region IDockItemProvider implementation
 		
 		public override string Name {
-			get {
-				return "Bookmark Items";
-			}
+			get { return "Bookmarks"; }
 		}
 		
 		public override string Icon { get { return "folder-home;;user-home"; } }
@@ -170,9 +169,8 @@ namespace Bookmarks
 				using (DataOutputStream writer = new DataOutputStream (tempFile.AppendTo (FileCreateFlags.None, null))) {
 					string line;
 					ulong length;
-					while ((line = reader.ReadLine (out length, null)) != null) {
+					while ((line = reader.ReadLine (out length, null)) != null)
 						writer.PutString (string.Format ("{0}{1}", line, reader.NewLineString ()), null);
-					}
 					
 					writer.PutString (string.Format ("{0}{1}", bookmark.Uri, reader.NewLineString ()), null);
 				}
@@ -209,9 +207,9 @@ namespace Bookmarks
 					string line;
 					ulong length;
 					while ((line = reader.ReadLine (out length, null)) != null) {
-						if (line.Split (' ')[0] != bookmark.Uri)
+						if (line.Split (' ')[0] != bookmark.Uri) {
 							writer.PutString (string.Format ("{0}{1}", line, reader.NewLineString ()), null);
-						else {
+						} else {
 							items.Remove (bookmark);
 							Items = InnerItems;
 							Log<BookmarksItemProvider>.Debug ("Removing '{0}'", bookmark.HoverText);
@@ -227,9 +225,7 @@ namespace Bookmarks
 		}
 		
 		public override bool Separated {
-			get {
-				return true;
-			}
+			get { return true; }
 		}
 		
 		public override void Dispose ()
