@@ -34,7 +34,7 @@ namespace Mounter
 		
 		public override string Name {
 			get {
-				return "Mount";
+				return "Mounter";
 			}
 		}
 		
