@@ -50,8 +50,6 @@ namespace RecentDocuments
 		FileDockItem currentFile;
 		FileMonitor watcher;
 		
-		RecentDocumentsItemProvider recentOwner;
-		
 		public FileDockItem CurrentFile {
 			get {
 				return currentFile;
@@ -80,9 +78,8 @@ namespace RecentDocuments
 			RefreshRecentDocs ();
 		}
 		
-		public RecentDocumentsItem (RecentDocumentsItemProvider recentOwner)
+		public RecentDocumentsItem ()
 		{
-			this.recentOwner = recentOwner;
 			RecentDocs = new List<FileDockItem> ();
 			
 			Gtk.RecentManager.Default.Changed += delegate { RefreshRecentDocs (); };
@@ -92,23 +89,26 @@ namespace RecentDocuments
 		
 		void RefreshRecentDocs ()
 		{
-			GLib.List recent_items = new GLib.List (Gtk.RecentManager.Default.Items.Handle, typeof(Gtk.RecentInfo));
-			CanClear = recent_items.Cast<Gtk.RecentInfo> ().Count () != 0;
+			GLib.List recent_items = new GLib.List (Gtk.RecentManager.Default.Items.Handle, typeof(Gtk.RecentInfo), false, false);
+			IEnumerable<Gtk.RecentInfo> infos = recent_items.OfType<Gtk.RecentInfo> ();
+			CanClear = recent_items.Count > 0;
 			
 			lock (RecentDocs) {
 				foreach (FileDockItem f in RecentDocs)
 					f.Dispose ();
 				RecentDocs.Clear ();
 				
-				RecentDocs.AddRange (recent_items.Cast<Gtk.RecentInfo> ()
-				                     .Where (it => it.Exists ())
+				RecentDocs.AddRange (infos.Where (it => it.Exists ())
 									 .OrderByDescending (f => f.Modified)
 				                     .Take (NumRecentDocs)
 				                     .Select (f => FileDockItem.NewFromUri (f.Uri)));
 			}
 			
+			foreach (Gtk.RecentInfo ri in infos)
+				ri.Dispose ();
+			recent_items.Dispose ();			
+			
 			UpdateInfo ();
-			recentOwner.UpdateItems ();
 		}
 		
 		void UpdateInfo ()
