@@ -54,17 +54,8 @@ namespace RecentDocuments
 		
 		public RecentDocumentsItemProvider ()
 		{
-			docs = new RecentDocumentsItem (this);
-			UpdateItems ();
-			Gtk.RecentManager.Default.Changed += delegate { UpdateItems (); };
-		}
-		
-		public void UpdateItems ()
-		{
-			if ((docs == null || docs.CurrentFile == null) && Items.Count () == 1)
-				Items = Enumerable.Empty<AbstractDockItem> ();
-			if (docs != null && docs.CurrentFile != null && Items.Count () == 0)
-				Items = docs.AsSingle<AbstractDockItem> ();
+			docs = new RecentDocumentsItem ();
+			Items = docs.AsSingle<AbstractDockItem> ();
 		}
 		
 		void ClearRecent ()
