@@ -64,7 +64,7 @@ namespace Trash
 
 		void HandleChanged (object o, ChangedArgs args)
 		{			
-			Gtk.Application.Invoke (delegate {
+			DockServices.System.RunOnMainThread (delegate {
 				Update ();
 			});
 		}
@@ -227,7 +227,7 @@ namespace Trash
 			// eneble events again
 			TrashMonitor.Changed += HandleChanged;
 
-			Gtk.Application.Invoke (delegate {
+			DockServices.System.RunOnMainThread (delegate {
 				Update ();
 				OnPaintNeeded ();
 			});
