@@ -87,7 +87,7 @@ namespace WeatherDocklet
 		/// </summary>
 		void HandleWeatherReloading ()
 		{
-			Gtk.Application.Invoke (delegate {
+			DockServices.System.RunOnMainThread (delegate {
 				HoverText = Catalog.GetString ("Fetching data...");
 				if (Status != WeatherDockletStatus.Initializing && Status != WeatherDockletStatus.ManualReload) {
 					Status = WeatherDockletStatus.Reloading;
@@ -110,7 +110,7 @@ namespace WeatherDocklet
 		/// </param>
 		void HandleWeatherError (object sender, WeatherErrorArgs e)
 		{
-			Gtk.Application.Invoke (delegate {
+			DockServices.System.RunOnMainThread (delegate {
 				HoverText = e.Error;
 				Icon = "weather-few-clouds";
 				Status = WeatherDockletStatus.Error;
@@ -124,7 +124,7 @@ namespace WeatherDocklet
 		/// </summary>
 		void HandleWeatherUpdated ()
 		{
-			Gtk.Application.Invoke (delegate {
+			DockServices.System.RunOnMainThread (delegate {
 				IWeatherSource weather = WeatherController.Weather;
 				
 				string feelsLike = "";
