@@ -49,8 +49,10 @@ class DockyTerminalItem(DockyItem):
 
 	def menu_pressed(self, menu_id):
 		if self.id_map[menu_id] == "Open Terminal Here":
-			os.chdir(self.path);
+			oldDir = os.getcwd()
+			os.chdir(self.path)
 			os.system ('%s &' % self.terminal)
+			os.chdir(oldDir)
 		
 	def add_menu_item(self, name, icon):
 		menu_id = self.iface.AddMenuItem(name, icon, "actions")
